@@ -29,11 +29,10 @@ require 'aprs4r/AX25SocketConfiguration'
 require 'aprs4r/RawSocketConfiguration'
 require 'aprs4r/TestSocketConfiguration'
 
-require 'aprs4r/BeaconConfiguration'
-require 'aprs4r/GatewayConfiguration'
-require 'aprs4r/DigipeaterConfiguration'
-
 require 'aprs4r/PluginConfiguration'
+require 'aprs4r/BeaconPluginConfiguration'
+require 'aprs4r/GatewayPluginConfiguration'
+require 'aprs4r/DigipeaterPluginConfiguration'
 require 'aprs4r/LCD4LinuxPluginConfiguration'
 require 'aprs4r/XMLDataPluginConfiguration'
 require 'aprs4r/QueryPluginConfiguration'
@@ -41,6 +40,7 @@ require 'aprs4r/MessagePluginConfiguration'
 require 'aprs4r/ISServerConfiguration'
 require 'aprs4r/WeatherConfiguration'
 require 'aprs4r/WMRWeatherConfiguration'
+require 'aprs4r/LogPluginConfiguration'
 
 
 class APRS4RConfiguration
