@@ -208,18 +208,8 @@ class APRSMessage
       index = @@APRS_POSITION_LATITUDE_INDEX[type]
       length = 8
 
-      @@logger.debug( "latitude: #{payload[index...index+length]}")
-      
       if index + length < payload.length
-        degree = payload[index...index+2].to_f
-        minute = payload[index+2...index+4].to_f
-        second = payload[index+5...index+7].to_f
-
-        latitude = degree + ((minute + (second / 60.0)) / 60.0)
-
-        if payload[index+8] == 'S'
-          latitude *= -1.0
-        end
+        latitude = APRSMessage.degree2decimal( payload[index...index+length])
       end
     end
 
@@ -236,25 +226,15 @@ class APRSMessage
       index = @@APRS_POSITION_LONGITUDE_INDEX[type]
       length = 9
 
-      @@logger.debug( "longitude: #{payload[index...index+length]}")
-      
       if index + length < payload.length
-        degree = payload[index...index+3].to_f
-        minute = payload[index+3...index+5].to_f
-        second = payload[index+6...index+8].to_f
-
-        longitude = degree + ((minute + (second / 60.0)) / 60.0)
-
-        if payload[index+9] == 'W'
-          longitude *= -1.0
-        end
+        longitude = APRSMessage.degree2decimal( payload[index...index+length])
       end
     end
 
     return longitude
   end
 
-
+  
   def has_extension?
     @@logger.info( "has_extension?")
 
@@ -608,6 +588,36 @@ class APRSMessage
   end
 
   
+  def APRSMessage.degree2decimal( position)
+    @@logger.info( "degree2decimal")
+
+    value = 0.0
+
+    if position.nil? || position.length < 8
+      return value
+    end
+
+    case position[position.length-1].chr
+    when 'N'
+      value = position[0...2].to_f + (position[2...4].to_f + position[5...7].to_f / 100.0) / 60.0
+      
+    when 'S'
+      value = position[0...2].to_f + (position[2...4].to_f + position[5...7].to_f / 100.0) / 60.0
+      value *= -1.0
+
+    when 'E'
+      value = position[0...3].to_f + (position[3...5].to_f + position[6...8].to_f / 100.0) / 60.0
+
+    when 'W'
+      value = position[0...3].to_f + (position[3...5].to_f + position[6...8].to_f / 100.0) / 60.0
+      value *= -1.0
+
+    end
+
+    return value
+  end
+
+
   def APRSMessage.APRS_PATH_RELAY
     return @@APRS_PATH_RELAY
   end
