@@ -38,6 +38,7 @@ class AX25Socket
     @type = configuration.type
     @enable = configuration.enable
     @device = configuration.device
+    @baudrate = configuration.baudrate
     @mode = configuration.mode
     @call = configuration.call
     @speed = configuration.speed
@@ -55,7 +56,7 @@ class AX25Socket
     @@logger.info( "initAX25Socket")
 
     if @mode.index( "kiss") == 0 
-      @socket = KISSDevice.new( @device, @call, @speed, @timeout, @mode)
+      @socket = KISSDevice.new( @device, @baudrate, @call, @speed, @timeout, @mode)
     end
 
     return
