@@ -22,11 +22,11 @@ require 'aprs4r/PluginConfiguration'
 
 class XMLDataPluginConfiguration < PluginConfiguration
 
-  attr_reader :file, :device, :call, :latitude, :longitude
-  attr_writer :file, :device, :call, :latitude, :longitude
+  attr_reader :file, :device, :call, :latitude, :longitude, :period, :timeout
+  attr_writer :file, :device, :call, :latitude, :longitude, :period, :timeout
 
   def to_yaml_properties
-    %w{ super @file @device @call @latitude @longitude}
+    %w{ super @file @device @call @latitude @longitude @period @timeout}
   end
 
 end
